==> toutdoux-1.2.4.tar.gz: ToutDoux-1.2.4/app/main.h <==
/*****************************************************************************/
/* main.c : module principal et ligne de commande
 * main.c : main module and command line
 *
 *
 * TouxDoux : Chtit gestionnaire de projet - A littl' project manager
 * Copyright (c) 2000 Philippe Roy
 * Auteur - Author : Philippe Roy <ph_roy@yahoo.com>
 *
 *
 * Ce programme est un logiciel libre ; vous pouvez le redistribuer et/ou le modifier
 * sous les termes de la licence publique gnrale GNU telle qu'elle est publie par
 * la Free Software Foundation ; soit la version 2 de la licence, ou
 * (comme vous voulez) toute version ultrieure.
 *
 * Ce programme est distribu dans l'espoir qu'il sera utile,
 * mais SANS AUCUNE GARANTIE ; mme sans la garantie de
 * COMMERCIALIT ou d'ADQUATION A UN BUT PARTICULIER. Voir la
 * licence publique gnrale GNU pour plus de dtails.
 *
 * Vous devriez avoir reu une copie de la licence publique gnrale GNU
 * avec ce programme ; si ce n'est pas le cas, crivez  la Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
/*****************************************************************************/


/*****************************************************************************/
/* Popt */
/*****************************************************************************/
gchar *file_popt;
gboolean mode_debug_popt;
gboolean mode_nocolor_popt;

/*****************************************************************************/
/* Definition */
/*****************************************************************************/
GtkObject *app_def (void);

/*****************************************************************************/
/* Main */
/*****************************************************************************/

/*****************************************************************************/
/* Menu */
/*****************************************************************************/
void editprop_show (void);
void quit_toutdoux (void);
void cogitation_show (void);
void bookmarks_show (void);
void messages_show (void);
void communication_url_show (void);
void communication_db_show (void);

/*****************************************************************************/
/* Module noyaux */
/*****************************************************************************/
void app_mod_core_def (void);

==> toutdoux-1.2.7.tar.gz: ToutDoux-1.2.7/app/main.h <==
/*****************************************************************************/
/* main.c : module principal et ligne de commande
 * main.c : main module and command line
 *
 *
 * TouxDoux : Chtit gestionnaire de projet - A littl' project manager
 * Copyright (c) 2000-2001 Philippe Roy
 * Auteur - Author : Philippe Roy <ph_roy@toutdoux.org>
 *
 *
 * Ce programme est un logiciel libre ; vous pouvez le redistribuer et/ou le modifier
 * sous les termes de la licence publique gnrale GNU telle qu'elle est publie par
 * la Free Software Foundation ; soit la version 2 de la licence, ou
 * (comme vous voulez) toute version ultrieure.
 *
 * Ce programme est distribu dans l'espoir qu'il sera utile,
 * mais SANS AUCUNE GARANTIE ; mme sans la garantie de
 * COMMERCIALIT ou d'ADQUATION A UN BUT PARTICULIER. Voir la
 * licence publique gnrale GNU pour plus de dtails.
 *
 * Vous devriez avoir reu une copie de la licence publique gnrale GNU
 * avec ce programme ; si ce n'est pas le cas, crivez  la Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
/*****************************************************************************/

/*****************************************************************************/
/*** Popt */
/*****************************************************************************/
gchar *file_popt;
gboolean mode_debug_popt;
gboolean mode_build_popt;
gboolean mode_nocolor_popt;

/*****************************************************************************/
/*** Dfinition - Definition */
/*****************************************************************************/
GtkObject *app_def (void);

/*****************************************************************************/
/*** Menu */
/*****************************************************************************/
void bench_show (void);
void etabliste_show (void);
void cogitation_show (void);
void bookmarks_show (void);
void quit_toutdoux (void);
void communication_url_show (void);
void communication_db_show (void);
void customize_show (void);
void presto_show (void);

/*****************************************************************************/
/*** Modules noyaux - Core modules */
/*****************************************************************************/
void app_mod_core_def (void);
